##Modal Results (.vmod)

Modal results are only created if enabled in the [Options](#main-form) tab. One file is created for each calculation and stored in the same directory as the .vecto file.

In Vecto 3 the structure of the modal data output has been revised and re-structured. Basically for every powertrain component the .vmod file contains the power at the input shaft and the individual power losses for every component. For the engine the power, torque and engine speed at the output shaft is given along with the internal power and torque used for computing the fuel consumption. See [Powertrain and Components Structure](#powertrain-and-components-structure) for schematics how the powertrain looks like and which positions in the powertrain the values represent.

Every line in the .vmod file represents the simulation interval from time - dt/2 to time + dt/2. All values represent the average power/torque/angular velocity during this simulation interval. If a certain power value can be described as function of the vehicle's acceleration the average power is calculated by
$P_{avg} = \frac{1}{simulation interval} \int{P(t) dt}$. 

**Note:** Columns for the torque converter operating point represent the torque/angular speed at the end of the simulation interval!

###Quantities:

 The following table lists the columns in the .vmod file:
	
**Note:** For dual-fuel vehicles the fuel consumption columns are present for each fuel (e.g., FC-Map_Diesel CI, FC-Map_NG CI).


| **Name**                   | **Unit**  | **Description**                                                                                                                                                                                                                                                                                                                                                                                                |
| -----------------          | --------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------                                                                                                                                                                                                                                             |
| time                       | [s]       | Absolute time. Timestamp at the middle of the current simulation interval [time - dt/2, time + dt/2]                                                                                                                                                                                                                                                                                                           |
| dt                         | [s]       | Length of the current simulation interval                                                                                                                                                                                                                                                                                                                                                                      |
| dist                       | [m]       | Distance the vehicle traveled at the end of the current simulation interval                                                                                                                                                                                                                                                                                                                                    |
| v_act                      | [km/h]    | Average vehicle speed in the current simulation interval                                                                                                                                                                                                                                                                                                                                                       |
| v_targ                     | [km/h]    | Target speed                                                                                                                                                                                                                                                                                                                                                                                                   |
| acc                        | [m/s^2]   | Vehicle's acceleration, constant during the current simulation interval                                                                                                                                                                                                                                                                                                                                        |
| grad                       | [%]       | Road gradient                                                                                                                                                                                                                                                                                                                                                                                                  |
| Gear                       | [-]       | Gear. "0" = clutch opened / neutral                                                                                                                                                                                                                                                                                                                                                                            |
| TC locked                  | 0/1       | For AT-Gearboxes: if the torque converter is locked or not                                                                                                                                                                                                                                                                                                                                                     |
| n_ice_avg                  | [1/min]   | Average engine speed in the current simulation interval. Used for interpolation of the engine's fuel consumption                                                                                                                                                                                                                                                                                               |
| T_ice_fcmap                | [Nm]      | Engine torque used for interpolation of the engine's fuel consumption. T_eng_fcmap is the sum of torque demand on the output shaft, torque demand of the auxiliaries                                                                                                                                                                                                             , and engine's inertia torque |
| Tq_full                    | [Nm]      | Engine's transient maximum torque (see [transient full load](#engine-transient-full-load))                                                                                                                                                                                                                                                                                                                     |
| Tq_drag                    | [Nm]      | Engine's drag torque, interpolated from the full-load curve                                                                                                                                                                                                                                                                                                                                                    |
| P_ice_fcmap                | [kW]      | Total power the engine has to provide, computed from n_eng_avg and T_eng_fcmap                                                                                                                                                                                                                                                                                                                                 |
| P_ice_full                 | [kW]      | Engine's transient maximum power  (see [transient full load](#engine-transient-full-load))                                                                                                                                                                                                                                                                                                                     |
| P_ice_full_stat            | [kW]      | Engine's stationary maximum power                                                                                                                                                                                                                                                                                                                                                                              |
| P_ice_drag                 | [kW]      | Engine's drag power                                                                                                                                                                                                                                                                                                                                                                                            |
| P_ice_inertia              | [kW]      | Power loss/gain due to the engine's inertia                                                                                                                                                                                                                                                                                                                                                                    |
| P_ice_out                  | [kW]      | Power provided at the engine's output shaft                                                                                                                                                                                                                                                                                                                                                                    |
| P_REESS_T                  | [kW]      | Electric power provided at the battery's connector                                                                                                                                                                                                                                                                                                                                                             |
| P_REESS_int                | [kW]      | Internal battery power                                                                                                                                                                                                                                                                                                                                                                                         |
| P_REESS_loss               | [kW]      | Losses of the battery due to its internal resistance.                                                                                                                                                                                                                                                                                                                                                          |
| P_REESS_charge_max         | [kW]      | Maximum power the battery can be charged with                                                                                                                                                                                                                                                                                                                                                                  |
| P_REESS_discharge_max      | [kW]      | Maximum power the battery can provide                                                                                                                                                                                                                                                                                                                                                                          |
| REESS SOC                  | [%]       | The battery's current state of charge                                                                                                                                                                                                                                                                                                                                                                          |
| U_REESS_T                  | [V]       | Voltage at the battery's connector                                                                                                                                                                                                                                                                                                                                                                             |
| U_0_REESS                  | [V]       | Battery's internal voltage                                                                                                                                                                                                                                                                                                                                                                                     |
| I_REESS                    | [A]       | Current charging/discharging the battery.                                                                                                                                                                                                                                                                                                                                                                      |
| i_\<POS>-em                | [-]       | Ratio between drivetrain and electric motor shaft
| P_\<POS>\_out              | [kW]      | Power at the electric machine's output shaft (drivetrain)                                                                                                                                                                                                                                                                                                                                                      |
| P_\<POS>\_mech             | [kW]      | Mechanical power the electric machine applies to the drivetrain. Positive values mean that electric energy is generated while negative values mean that the electric machine drives the vehicle.                                                                                                                                                                                                               |
| P_\<POS>\_in               | [kW]      | Power at the electric machine's input shaft (drivetrain)                                                                                                                                                                                                                                                                                                                                                       |
| P_\<POS>\_transm_loss      | [kW]      | Losses of the transmission stage inside the electric motor component                                                                                                                                                                                                                                                                                                                                           |
| P_\<POS>-em_mech           | [kW]      | Power at the shaft of the electric motor at position *POS*                                                                                                                                                                                                                                                                                                                                                     |
| P_\<POS>-em_inertia_loss   | [kW]      | Inertia loses of the electric machine                                                                                                                                                                                                                                                                                                                                                                          |
| P_\<POS>-em_mech_map       | [kW]      | Mechanical powerthe electric motor at position *POS* applies for driving or recuperation, including the electric motor's inertia                                                                                                                                                                                                                                                                               |
| P_\<POS>-em_loss           | [kW]      | Losses in the electric machine due to converting electric power to mechanical power                                                                                                                                                                                                                                                                                                                            |
| P_\<POS>-em_el             | [kW]      | Electric power generated or consumed by the elctric machine                                                                                                                                                                                                                                                                                                                                                    |
| P_\<POS>\_loss             | [kW]      | The total sum of losses of the electric motor at position *POS*. Calcualted as the difference of mecanical power applied at the drivetrain and the electrical power drawn from the REESS.                                                                                                                                                                                                                      |
| n_\<POS>-em_avg            | [rpm]     | Angular speed of the electric motor at position *POS*                                                                                                                                                                                                                                                                                                                                                          |
| T_\<POS>-em                | [Nm]      | Torque at the shaft of  electric motor at position *POS*. Positive values mean that the electric motor acts as generator, negative torque values mean that the electric motor propels the vehicle                                                                                                                                                                                                              |
| T_\<POS>-em_map            | [Nm]      | Torque internal torque of the electric motor at posision *POS*. Takes into account the electric motor's intertia. Positive values mean that the electric motor acts as generator, negative torque values mean that the electric motor propels the vehicle                                                                                                                                                      |
| T_\<POS>-em_drive_max      | [Nm]      | Maximum torque the electric machine can apply to propel the vehicle. This already considers the maximum current the battery can provide                                                                                                                                                                                                                                                                        |
| T_\<POS>-em_gen_max        | [Nm]      | Maximum torque the electric machine can apply to generate electric power. This already considers the maximum charge current the battery can handle.                                                                                                                                                                                                                                                            |
| P_\<POS>-em_drive_max      | [kW]      | Maximum power the electric motor can provide to drive the vehicle. This already considers the maximum electric power the battery can provide.                                                                                                                                                                                                                                                                  |
| P_\<POS>-em_gen_max        | [kW]      | Maximum power the electric machine can generate. This already considers the maximum charge power the battery can handle.                                                                                                                                                                                                                                                                                       |
| EM_OVL-\<POS>-em           | [%]       | Used capacity of the thermal overload buffer of the thermal derating model                                                                                                                                                                                                                                                                                                                                     |
| EM_\<POS>_off              | [-]       | Indicates if the electric motor at position *POS* is energized or not.                                                                                                                                                                                                                                                                                                                                         |
| P_clutch_loss              | [kW]      | Power loss in the clutch due to slipping when driving off                                                                                                                                                                                                                                                                                                                                                      |
| P_clutch_out               | [kW]      | Power at the clutch's out shaft. P_clutch_out = P_eng_out - P_clutch_loss                                                                                                                                                                                                                                                                                                                                      |
| P_TC_out                   | [kW]      | Power at the torque converter's out shaft. P_TC_out = P_eng_out - P_TC_loss                                                                                                                                                                                                                                                                                                                                    |
| P_TC_loss                  | [kW]      | Power loss in the torque converter                                                                                                                                                                                                                                                                                                                                                                             |
| P_aux_mech                 | [kW]      | Total power demand from the mechanical auxiliaries                                                                                                                                                                                                                                                                                                                                                             |
| P_aux_el                   | [kW]      | Total power demand from the electric auxiliaries connected to the REESS                                                                                                                                                                                                                                                                                                                                        |
| P_gbx_in                   | [kW]      | Power at the gearbox' input shaft                                                                                                                                                                                                                                                                                                                                                                              |
| P_gbx_loss                 | [kW]      | Power loss at the gearbox, interpolated from the loss-map + shift losses + inertia losses                                                                                                                                                                                                                                                                                                                      |
| P_gbx_shift                | [kW]      | Power loss due to gearshifts (AT gearbox)                                                                                                                                                                                                                                                                                                                                                                      |
| P_gbx_inertia              | [kW]      | Power loss due to the gearbox' inertia                                                                                                                                                                                                                                                                                                                                                                         |
| P_ret_in                   | [kW]      | Power at the retarder's input shaft. P_ret_in = P_gbx_in - P_gbx_loss - P_gbx_inertia                                                                                                                                                                                                                                                                                                                          |
| P_ret_loss                 | [kW]      | Power loss at the retarder, interpolated from the loss-map.                                                                                                                                                                                                                                                                                                                                                    |
| P_angle_in                 | [kW]      | Power at the anglegear's input shaft. Empty if no Anglegear is used.                                                                                                                                                                                                                                                                                                                                           |
| P_angle_loss               | [kW]      | Power loss at the anglegear, interpolated from the loss-map. Empty if no Anglegear is used.                                                                                                                                                                                                                                                                                                                    |
| P_axle_in                  | [kW]      | Power at the axle-gear input shaft. P_axle_in = P_ret_in - P_ret_loss ( - P_angle_loss if an Angulargear is used).                                                                                                                                                                                                                                                                                             |
| P_axle_loss                | [kW]      | Power loss at the axle gear, interpolated from the loss-map.                                                                                                                                                                                                                                                                                                                                                   |
| P_brake_in                 | [kW]      | Power at the brake input shaft (definition: serially mounted into the drive train between wheels and axle). P_brake_in = P_axle_in - P_axle_loss                                                                                                                                                                                                                                                               |
| P_brake_loss               | [kW]      | Power loss due to braking.                                                                                                                                                                                                                                                                                                                                                                                     |
| P_wheel_in                 | [kW]      | Power at the driven wheels. P_wheel_in = P_brake_in - P_brake_loss                                                                                                                                                                                                                                                                                                                                             |
| P_wheel_inertia            | [kW]      | Power loss due to the wheels' inertia                                                                                                                                                                                                                                                                                                                                                                          |
| P_trac                     | [kW]      | Vehicle's traction power. P_trac = P_wheel_in - P_wheel_inertia                                                                                                                                                                                                                                                                                                                                                |
| P_slope                    | [kW]      | Power loss/gain due to the road's slope                                                                                                                                                                                                                                                                                                                                                                        |
| P_air                      | [kW]      | Power loss due to air drag.                                                                                                                                                                                                                                                                                                                                                                                    |
| P_roll                     | [kW]      | Rolling resistance power loss.                                                                                                                                                                                                                                                                                                                                                                                 |
| P_veh_inertia              | [kW]      | Power loss due to the vehicle's inertia                                                                                                                                                                                                                                                                                                                                                                        |
| n_gbx_out_avg              | [rpm]     | Average angular speed at gearbox out shaft
| T_gbx_out                  | [Nm]      | Torque at gearbox out shaft
| T_gbx_in                   | [Nm]      | Torque at gearbox in shaft
| P_busAux_ES_HVAC           | [kW]      | (Average) electric power demand for the HVAC system (mainly ventilation power) *(only in .vmod file if bus auxiliaries are used)*                                                                                                                                                                                                                                                                              |
| P_busAux_ES_other          | [kW]      | (Average) electric power demand for all other electric consumers (lights, radio, kitchen, ...) *(only in .vmod file if bus auxiliaries are used)*                                                                                                                                                                                                                                                              |
| P_busAux_ES_consumer_sum   | [kW]      | (Average) total electric power demand of all electric consumers *(only in .vmod file if bus auxiliaries are used)*                                                                                                                                                                                                                                                                                             |
| P_busAux_ES_mech           | [kW]      | (Average) mechanical power demand of all electric consumers (considering alternator efficiency and pulley efficiency) *(only in .vmod file if bus auxiliaries are used)*                                                                                                                                                                                                                                       |
| P_busAux_ES_gen            | [kW]      | Generated electrical power. May be higher than the electric power demand in case of smart electrics or lower if engine stop/start is enabled. Fuel consumption is corrected in the [post-processing](#engine-fuel-consumption-correction). *(only in .vmod file if bus auxiliaries are used)*                                                                                                                  |
| Battery SoC                | [%]       | State of Charge of the battery (only used in case smart electric system is enabled) *(only in .vmod file if bus auxiliaries are used)*                                                                                                                                                                                                                                                                         |
| P_busAux_HVACmech_consumer | [kW]      | (Average) mechanical power demand for the HVAC system. *(only in .vmod file if bus auxiliaries are used)*                                                                                                                                                                                                                                                                                                      |
| P_busAux_HVACmech_gen      | [kW]      | Generated mechanical power for the HVAC system. May be 0 in case of engine stop/start. the total fuel consumption is corrected in the [post-processing](#engine-fuel-consumption-correction). *(only in .vmod file if bus auxiliaries are used)*                                                                                                                                                               |
| Nl_busAux_consumer         | [Nl]      | (Average) air demand of all consumers (air suspension, kneeling, brakes, pneumatic doors, ...). *(only in .vmod file if bus auxiliaries are used)*                                                                                                                                                                                                                                                             |
| Nl_busAux_gen              | [Nl]      | Generated air (assuming the compressor runs only a fraction of the simulation interval). *(only in .vmod file if bus auxiliaries are used)*                                                                                                                                                                                                                                                                    |
| Nl_busAux_gen_max          | [Nl]      | Maximum air that can be generated if the compressor runs the whole simulation interval. *(only in .vmod file if bus auxiliaries are used)*                                                                                                                                                                                                                                                                     |
| P_busAux_PS_gen            | [kW]      | Mechanical power demand for the air compressor to produce Nl_busAux_gen air. *(only in .vmod file if bus auxiliaries are used)*                                                                                                                                                                                                                                                                                |
| P_busAux_PS_gen_max        | [kW]      | Mechanical power demand for the air compressor to produce the maximum air volume. (Used for correcting the total fuel consumption in case of smart pneumatic system) *(only in .vmod file if bus auxiliaries are used)*                                                                                                                                                                                        |
| P_busAux_PS_gen_drag       | [kW]      | Mechanical power demand for the air compressor if no air is produced (compressor is in drag only, used for correcting the total fuel consumption in case of smart pneumatic system) *(only in .vmod file if bus auxiliaries are used)*                                                                                                                                                                         |
| P_DC/DC_In                 | [kW]      | Electrical power at the input (REESS side) of the DC/DC converter. *(only applicable in case the electric auxiliaries are connected to the high-voltage REESS, output is delayed by one simulation step)*                                                                                                                                                                                                      |
| P_DC/DC_Out                | [kW]      | Electrical power at the output (REESS side) of the DC/DC converter. *(only applicable in case the electric auxiliaries are connected to the high-voltage REESS, output is delayed by one simulation step)*                                                                                                                                                                                                     |
| P_DC/DC_missing            | [kW]      | Electrical power the DC/DC converter could not provide to the low-voltage auxiliaries becuase the REESS was already at its minimum SoC. This column is used in post-processing.                                                                                                                                                                                                                                |
| P_aux_<XXX>                | [kW]      | Mechanical power demand for every individual auxiliary. Only if the run has auxiliaries. In case of fully electrical auxiliaries for trucks the electrical power demand is converted to mechanical power using the alternator efficiency. For Buses with fully electrical auxiliaries the consumer is connected to the electrical system and thus the according column reports 0 power demand.                 |
| T_max_propulsion           | [Nm]      | Maximum allowed propulsion torque at gearbox input shaft                                                                                                                                                                                                                                                                                                                                                       |
| P_WHR_el                   | [kW]      | Power generated by an electric WHR system, interpolated from WHR map.                                                                                                                                                                                                                                                                                                                                          |
| P_WHR_el_corr              | [kW]      | Power generated by an electric WHR system after applying                                                                                                                                                                                                                                                                                                                                                       |
| P_WHR_mech                 | [kW]      | Power generated by an mechanical WHR system, interpolated from WHR map.                                                                                                                                                                                                                                                                                                                                        |
| P_WHR_mech_corr            | [kW]      | Power generated by an mechanical WHR system after applying                                                                                                                                                                                                                                                                                                                                                     |
| P_aux_ESS_mech_ICE_off     | [kW]      | Power demand of the auxiliaries 'missing' if the ICE is off.T he final fuel consumption (.vsum) is correctedd for this power demand in a [post-processing step](#engine-fuel-consumption-correction). This power demand has no influence on FC-Map.                                                                                                                                                            |
| P_aux_ESS_mech_ICE_on      | [kW]      | Power demand of the auxiliaries 'missing' in case the ICE would be on during actual ICE off periods. The final fuel consumption (.vsum) is correctedd for this power demand in a [post-processing step](#engine-fuel-consumption-correction). This power demand has no influence on FC-Map.                                                                                                                    |
| P_ice_start                | [kW]      | Power demand for starting the engine after an engine-off period multiplied by the engine start/stop utility factor. P_ice_start = [E_ice_start](#advanced-driver-assistant-systems-engine-stopstart) / dt. The final fuel consumption (.vmod) is corrected for this power demand in a [post-processing step](#engine-fuel-consumption-correction). This power demand has no influence on FC-Map.      |
| P_PTO_consum               | [kW]      | Power demand from the PTO consumer. Only if the vehicle has a PTO consumer.                                                                                                                                                                                                                                                                                                                                    |
| P_PTO_transmission         | [kW]      | Power demand from the PTO transmission. Only if the vehicle has a PTO consumer.                                                                                                                                                                                                                                                                                                                                |
| P_PTO_RoadSweeping         | [kW]	     | Power demand from the PTO in PTO mode 2. Only in engineering mode if PTO mode 2 is activated.                                                                                                                                                                                                                                                                                                                  |
| P_PTO_DuringDrive          | [kW]	     | Power demand from the PTO cycle in PTO mode 3. Only in engineering mode if PTO mode 3 is activated.                                                                                                                                                                                                                                                                                                            |
| TCnu                       | [-]       | Torque converter operating point:  speed ratio                                                                                                                                                                                                                                                                                                                                                                 |
| TCmu                       | [-]       | Torque converter operating point:  torque ratio                                                                                                                                                                                                                                                                                                                                                                |
| T_TC_out                   | [Nm]      | Torque converter operating point:  output torque                                                                                                                                                                                                                                                                                                                                                               |
| n_TC_out                   | [rpm]     | Torque converter operating point:  output speed                                                                                                                                                                                                                                                                                                                                                                |
| T_TC_in                    | [Nm]      | Torque converter operating point:  input torque                                                                                                                                                                                                                                                                                                                                                                |
| n_TC_in                    | [rpm]     | Torque converter operating point:  input speed                                                                                                                                                                                                                                                                                                                                                                 |
| FC-Map<\_FuelName>         | [g/h]     | Fuel consumption interpolated from FC map. *Note:* The fuel name is only stated in case of duel fuel engines.                                                                                                                                                                                                                                                                                                                                                                    |
| FC-NCVc<\_FuelName>        | [g/h]     | Fuel consumption corrected for different NCV values in VECTO and VECTO Engine (FC-NCVc = FC-Map * LowerHeatingValueVectoEngine(fuel) / LowerHeatingValueVecto(fuel) )                                                                                                                                                                                                                                          |
| FC-WHTCc<\_FuelName>       | [g/h]     | Fuel consumption after [WHTC Correction](#engine-fuel-consumption-calculation) (FC-WHTCc = FC-NCVc * WHTCCorrectionFactor(cycle, fuel) )                                                                                                                                                                                                                                                                       |
| FC-Final_mod<\_FuelName>   | [g/h]     | Instantaneous final fuel consumption value after all applicable corrections. (FC-Final_mod = FC-ESS)                                                                                                                                                                                                                                                                                                           |
| EcoRollConditionsMet       |           | 0 if the conditions for switching to eco-roll are _not_ met, 1 if the conditions for eco-roll are met - eco roll is activated after the activation delay (2s in declaration mode)                                                                                                                                                                                                                              |
| PCCSegment                 |           | 1 if a PCC segment was identified in the pre-processing (gradient below threshold where vehicle accelerates on its own without engine power) , 0 otherwise                                                                                                                                                                                                                                                     |
| PCCState                   |           | 0: not inside PCC segment, 1: inside PCC segment, 2: PCC use-case 1 active, 3: PCC use-case 2 active                                                                                                                                                                                                                                                                                                           |
| ICE On                     |           | 0 if the combustion engine is switched off (either during stand-still or eco-roll), 1 otherwise                                                                                                                                                                                                                                                                                                                |
 

**Note:** The fuel name is only added to the fuel-consumption signals in case of dual-fuel engines.

P_eng_FCmap = T_eng_fcmap * n_eng_avg

P_eng_fcmap = P_eng_out + P_AUX + P_eng_inertia ( + P_PTO_Transm + P_PTO_Consumer ) = P_loss_total + P_AUX + P_eng_inertia

P_loss_total = P_clutch_loss + P_gbx_loss + P_ret_loss + P_gbx_inertia + P_angle_loss + P_axle_loss + P_brake_loss +
								P_wheel_inertia + P_air + P_roll + P_grad + P_veh_inertia (+ P_PTOconsumer + P_PTO_transm)

P_trac = P_veh_inertia + P_roll + P_air + P_slope
